@@ -21,6 +21,9 @@ public:
     friend const QDBusArgument &operator>>(const QDBusArgument &arg, ScreenRect &rect);
     friend QDBusArgument &operator<<(QDBusArgument &arg, const ScreenRect &rect);
 
+    bool operator==(const ScreenRect &rect);
+    bool operator!=(const ScreenRect &rect);
+
 private:
     qint16 x;
     qint16 y;
