@@ -72,8 +72,6 @@ void ItemWidget::setTextShown(const QString &length)
 {
     QFont font = m_contentLabel->font();
 
-    font.setItalic(true);
-
     m_contentLabel->setFont(font);
 
     m_contentLabel->setText(true);
@@ -247,7 +245,7 @@ void ItemWidget::initUI()
     titleWidget->setFixedHeight(ItemTitleHeight);
 
     QFont font = DFontSizeManager::instance()->t4();
-    font.setWeight(75);
+    font.setWeight(QFont::Thin);
     m_nameLabel->setFont(font);
     m_nameLabel->setAlignment(Qt::AlignVCenter | Qt::AlignLeft);
     m_timeLabel->setAlignment(Qt::AlignVCenter | Qt::AlignRight);
@@ -261,7 +259,7 @@ void ItemWidget::initUI()
     //布局
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
     mainLayout->setSpacing(0);
-    mainLayout->setMargin(0);
+    mainLayout->setContentsMargins(0, 0, 0, 0);
     mainLayout->addWidget(titleWidget, 0, Qt::AlignTop);
 
     QHBoxLayout *layout = new QHBoxLayout;
@@ -442,7 +440,7 @@ QString ItemWidget::CreateTimeString(const QDateTime &time)
     if (time.daysTo(t) >= 1 && time.daysTo(t) < 2) { //昨天发生的
         text = tr("Yesterday") + time.toString(" hh:mm");
     } else if (time.daysTo(t) >= 2 && time.daysTo(t) < 7) { //昨天以前，一周以内
-        text = time.toString("ddd hh:mm");
+        text = QLocale::system().toString(time, "ddd hh:mm");
     } else if (time.daysTo(t) >= 7) { //一周前以前的
         text = time.toString("yyyy/MM/dd");
     } else if (time.secsTo(t) < 60 && time.secsTo(t) >= 0) { //60秒以内
@@ -486,8 +484,8 @@ QPixmap ItemWidget::getIconPixmap(const QIcon &icon, const QSize &size, qreal pi
     //             而且，在有些QIconEngine的实现中，会去调用另一个QIcon::pixmap，导致 pixmapSize 在这种嵌套调用中越来越大
     //             最终会获取到一个是期望大小几倍的图片，由于图片太大，会很快将 QPixmapCache 塞满，导致后面再调用QIcon::pixmap
     //             读取新的图片时无法缓存，非常影响图片绘制性能。此处在获取图片前禁用 Qt::AA_UseHighDpiPixmaps，自行处理图片大小问题
-    bool useHighDpiPixmaps = qApp->testAttribute(Qt::AA_UseHighDpiPixmaps);
-    qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, false);
+    // bool useHighDpiPixmaps = qApp->testAttribute(Qt::AA_UseHighDpiPixmaps);
+    // qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, false);
 
     QSize icon_size = icon.actualSize(size, mode, state);
 
@@ -498,7 +496,7 @@ QPixmap ItemWidget::getIconPixmap(const QIcon &icon, const QSize &size, qreal pi
     QPixmap px = icon.pixmap(pixmapSize, mode, state);
 
     // restore the value
-    qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, useHighDpiPixmaps);
+    // qApp->setAttribute(Qt::AA_UseHighDpiPixmaps, useHighDpiPixmaps);
 
     if (px.width() > icon_size.width() * pixelRatio) {
         px.setDevicePixelRatio(px.width() * 1.0 / qreal(icon_size.width()));
@@ -676,7 +674,7 @@ void ItemWidget::paintEvent(QPaintEvent *event)
 void ItemWidget::mouseDoubleClickEvent(QMouseEvent *event)
 {
     onSelect();
-    return DWidget::mousePressEvent(event);
+    return DWidget::mouseDoubleClickEvent(event);
 }
 
 void ItemWidget::focusInEvent(QFocusEvent *event)
