@@ -37,7 +37,6 @@ MainWindow::MainWindow(QWidget *parent)
     : DBlurEffectWidget(parent)
     , m_displayInter(new DBusDisplay("org.deepin.dde.Display1", "/org/deepin/dde/Display1", QDBusConnection::sessionBus(), this))
     , m_daemonDockInter(new DBusDaemonDock("org.deepin.dde.daemon.Dock1", "/org/deepin/dde/daemon/Dock1", QDBusConnection::sessionBus(), this))
-    , m_dockInter(new DBusDockInterface)
     , m_appearanceInter(new DDBusInterface(AppearanceService, AppearancePath, AppearanceInterface, QDBusConnection::sessionBus(), this))
     , m_regionMonitor(nullptr)
     , m_content(new DWidget(parent))
@@ -50,6 +49,8 @@ MainWindow::MainWindow(QWidget *parent)
     , m_wmHelper(DWindowManagerHelper::instance())
     , m_trickTimer(new QTimer)
     , m_windowHandle(new DPlatformWindowHandle(this, this))
+    , m_isWayland(qGuiApp->platformName() == QStringLiteral("wayland"))
+    , m_currentMargins(WindowMargin, WindowMargin, WindowMargin, WindowMargin)
 {
     initUI();
     initAni();
@@ -86,10 +87,33 @@ void MainWindow::Toggle()
 
 void MainWindow::geometryChanged()
 {
-    adjustPosition();
+    // Wayland layer-shell implementation
+    auto layerShellWnd = ds::DLayerShellWindow::get(windowHandle());
+    QMargins margins(WindowMargin, WindowMargin, WindowMargin, WindowMargin);
+    auto dockGeometry = m_daemonDockInter->frontendWindowRect();
+    // frontendWindowRect is physical screen rect, we need to convert it to logical screen rect.
+    dockGeometry = QRect(
+        dockGeometry.x() / qApp->devicePixelRatio(),
+        dockGeometry.y() / qApp->devicePixelRatio(),
+        dockGeometry.width() / qApp->devicePixelRatio(),
+        dockGeometry.height() / qApp->devicePixelRatio()
+    );
 
-    setX(WindowMargin);
+    // dock not hide and in current screen
+    if (m_daemonDockInter->hideState() != 2 && (window() && window()->screen()->geometry().contains(dockGeometry))) {
+        switch (m_daemonDockInter->position()) {
+            case DOCK_TOP: margins.setTop(dockGeometry.height() + WindowMargin); break;
+            case DOCK_BOTTOM: margins.setBottom(dockGeometry.height() + WindowMargin); break;
+            case DOCK_LEFT: break;
+            case DOCK_RIGHT: margins.setRight(dockGeometry.width() + WindowMargin); break;
+        }
+    }
 
+    layerShellWnd->setRightMargin(margins.right());
+    layerShellWnd->setBottomMargin(margins.bottom());
+    layerShellWnd->setTopMargin(margins.top());
+
+    // FIXME: Legacy animation?
     //init animation by 'm_rect'
     m_xAni->setStartValue(WindowMargin);
     m_xAni->setEndValue(0);
@@ -98,6 +122,63 @@ void MainWindow::geometryChanged()
     m_widthAni->setEndValue(0);
 }
 
+void MainWindow::onFrontendWindowRectChanged(const QRect &rect)
+{
+    if (!window() || !window()->screen()) {
+        return;
+    }
+
+    QRect dockGeometry = QRect(
+        rect.x() / qApp->devicePixelRatio(),
+        rect.y() / qApp->devicePixelRatio(),
+        rect.width() / qApp->devicePixelRatio(),
+        rect.height() / qApp->devicePixelRatio()
+    );
+
+    QRect screenGeometry = window()->screen()->geometry();
+    QMargins newMargins(WindowMargin, WindowMargin, WindowMargin, WindowMargin);
+    
+    if (dockGeometry.width() > 0 && dockGeometry.height() > 0) {
+        switch (m_daemonDockInter->position()) {
+            case DOCK_TOP: {
+                int visibleHeight = qMax(0, dockGeometry.y() + dockGeometry.height() - screenGeometry.top());
+                newMargins.setTop(visibleHeight + WindowMargin);
+                break;
+            }
+            case DOCK_BOTTOM: {
+                int visibleHeight = qMax(0, screenGeometry.bottom() + 1 - dockGeometry.y());
+                newMargins.setBottom(visibleHeight + WindowMargin);
+                break;
+            }
+            case DOCK_LEFT: {
+                break;
+            }
+            case DOCK_RIGHT: {
+                int visibleWidth = qMax(0, screenGeometry.right() + 1 - dockGeometry.x());
+                newMargins.setRight(visibleWidth + WindowMargin);
+                break;
+            }
+        }
+    }
+
+
+    if (newMargins != m_currentMargins) {
+        m_currentMargins = newMargins;
+        
+        auto layerShellWnd = ds::DLayerShellWindow::get(windowHandle());
+        layerShellWnd->setLeftMargin(newMargins.left());
+        layerShellWnd->setRightMargin(newMargins.right());
+        layerShellWnd->setBottomMargin(newMargins.bottom());
+        layerShellWnd->setTopMargin(newMargins.top());
+    }
+
+    m_xAni->setStartValue(WindowMargin);
+    m_xAni->setEndValue(0);
+
+    m_widthAni->setStartValue(m_rect.width());
+    m_widthAni->setEndValue(0);
+}
+
 void MainWindow::showAni()
 {
     if (m_trickTimer->isActive()) {
@@ -106,14 +187,12 @@ void MainWindow::showAni()
     m_trickTimer->start();
 
     if (!m_hasComposite) {
-        move(m_rect.x() + WindowMargin, m_rect.y());
-        setFixedWidth(m_rect.width());
         show();
         return;
     }
 
     move(m_rect.x(), m_rect.y());
-    setFixedWidth(0);
+    // setFixedWidth(0); // FIXME: Remove legacy animation. This line is commented out because it interferes with layershell anchoring
 
     show();
     m_aniGroup->setDirection(QAbstractAnimation::Backward);
@@ -191,9 +270,18 @@ void MainWindow::registerMonitor()
     });
 }
 
+void MainWindow::updatePrimaryScreen()
+{
+    if (!window())
+        return;
+
+    window()->setScreen(qApp->primaryScreen());
+    updateGeometry();
+}
+
 void MainWindow::initUI()
 {
-    setWindowFlags(Qt::FramelessWindowHint | Qt::Tool  | Qt::MSWindowsFixedSizeDialogHint | Qt::WindowStaysOnTopHint);
+    setWindowFlags(Qt::FramelessWindowHint);
     setAttribute(Qt::WA_TranslucentBackground);
 
     QVBoxLayout *mainLayout = new QVBoxLayout();
@@ -231,7 +319,7 @@ void MainWindow::initUI()
 
     QHBoxLayout *layout = new QHBoxLayout(this);
     layout->setSpacing(0);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(m_content);
 
     setMaskAlpha(static_cast<int>(this->opacity() * 255));
@@ -243,6 +331,23 @@ void MainWindow::initUI()
     m_cornerRadius = m_windowHandle->windowRadius();
     m_themeType= DGuiApplicationHelper::instance()->themeType();
     m_windowHandle->setBorderWidth(1);
+
+    // LayerShell-implemented anchoring
+    auto layerShellWnd = ds::DLayerShellWindow::get(windowHandle());
+
+    layerShellWnd->setAnchors({ ds::DLayerShellWindow::AnchorRight,
+                                ds::DLayerShellWindow::AnchorBottom,
+                                ds::DLayerShellWindow::AnchorTop });
+    layerShellWnd->setLayer(ds::DLayerShellWindow::LayerOverlay);
+    // FIXME: X11 layer shell emulation is broken.
+    // When exclusion zone is set to -1, the X11 emulation puts the window to the center.
+    // When exclusion zone is set to 0, DDE Dock will not occupy the space before clipboard (works like -1 in Wayland)
+    layerShellWnd->setExclusiveZone(m_isWayland ? -1 : 0);
+    layerShellWnd->setKeyboardInteractivity(ds::DLayerShellWindow::KeyboardInteractivityOnDemand);
+    // Initial size
+    setFixedWidth(WindowWidth);
+
+    updatePrimaryScreen();
 }
 
 void MainWindow::initAni()
@@ -263,6 +368,7 @@ void MainWindow::initAni()
 
 void MainWindow::initConnect()
 {
+    connect(qApp, &QGuiApplication::primaryScreenChanged, this, &MainWindow::updatePrimaryScreen, Qt::UniqueConnection);
     connect(DisplayManager::instance(), &DisplayManager::screenInfoChanged, this, &MainWindow::geometryChanged, Qt::QueuedConnection);
     connect(m_displayInter, &DBusDisplay::PrimaryRectChanged, this, &MainWindow::geometryChanged, Qt::QueuedConnection);
 
@@ -274,7 +380,8 @@ void MainWindow::initConnect()
         hideAni();
     });
 
-    connect(m_dockInter, &DBusDockInterface::geometryChanged, this, &MainWindow::geometryChanged, Qt::UniqueConnection);
+    connect(m_daemonDockInter, &DBusDaemonDock::FrontendWindowRectChanged, this, &MainWindow::onFrontendWindowRectChanged,  Qt::UniqueConnection);
+    connect(m_daemonDockInter, &DBusDaemonDock::PositionChanged, this, &MainWindow::geometryChanged);
 
     connect(m_wmHelper, &DWindowManagerHelper::hasCompositeChanged, this, &MainWindow::CompositeChanged, Qt::QueuedConnection);
 
@@ -341,7 +448,7 @@ void MainWindow::adjustPosition()
     rect.setWidth(WindowWidth);
     rect.setHeight(int(std::round(qreal(rect.height()))));
 
-    QRect dockRect = m_dockInter->geometry();
+    QRect dockRect = m_daemonDockInter->frontendWindowRect();
     dockRect.setWidth(int(std::round(qreal(dockRect.width()))));
     dockRect.setHeight(int(std::round(qreal(dockRect.height()))));
 
@@ -388,7 +495,7 @@ void MainWindow::adjustPosition()
 
 QRect MainWindow::getDisplayScreen()
 {
-    QPoint dockCenterPoint = QRect(m_dockInter->geometry()).center() / qApp->devicePixelRatio();
+    QPoint dockCenterPoint = QRect(m_daemonDockInter->frontendWindowRect()).center() / qApp->devicePixelRatio();
 
     for (auto s : qApp->screens()) {
         QRect rect(s->geometry().x() / qApp->devicePixelRatio(),
@@ -436,4 +543,13 @@ void MainWindow::hideEvent(QHideEvent *event)
 {
     Q_EMIT clipboardVisibleChanged(false);
     DBlurEffectWidget::hideEvent(event);
-}
\ No newline at end of file
+}
+
+bool MainWindow::event(QEvent *event)
+{
+    if (event->type() == QEvent::WindowDeactivate) {
+        hideAni();
+    }
+
+    return DBlurEffectWidget::event(event);
+}
